==> tool-sql-2.6.0-pre3-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/StateMachineState.java <==
package io.ciera.tool.sql.ooaofooa.statemachine;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.statemachine.State;
import io.ciera.tool.sql.ooaofooa.instance.I_INS;
import io.ciera.tool.sql.ooaofooa.instance.I_INSSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHome;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransition;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SM;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntry;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntrySet;
import io.ciera.tool.sql.ooaofooa.statemachine.Transition;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;


public interface StateMachineState extends IModelInstance<StateMachineState,Sql> {

    // attributes
    public void setSMstt_ID( UniqueId m_SMstt_ID ) throws XtumlException;
    public UniqueId getSMstt_ID() throws XtumlException;
    public UniqueId getSM_ID() throws XtumlException;
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException;
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException;
    public UniqueId getSMspd_IDdeprecated() throws XtumlException;
    public void setName( String m_Name ) throws XtumlException;
    public String getName() throws XtumlException;
    public void setNumb( int m_Numb ) throws XtumlException;
    public int getNumb() throws XtumlException;
    public int getFinal() throws XtumlException;
    public void setFinal( int m_Final ) throws XtumlException;


    // operations


    // selections
    default public void addR2915_defines_state_of_I_INS( I_INS inst ) {}
    default public void removeR2915_defines_state_of_I_INS( I_INS inst ) {}
    public I_INSSet R2915_defines_state_of_I_INS() throws XtumlException;
    default public void setR4758_is_transformed_from_State( State inst ) {}
    public State R4758_is_transformed_from_State() throws XtumlException;
    default public void setR501_SM_SM( SM_SM inst ) {}
    public SM_SM R501_SM_SM() throws XtumlException;
    default public void addR503_receives_StateEventMatrixEntry( StateEventMatrixEntry inst ) {}
    default public void removeR503_receives_StateEventMatrixEntry( StateEventMatrixEntry inst ) {}
    public StateEventMatrixEntrySet R503_receives_StateEventMatrixEntry() throws XtumlException;
    default public void addR506_is_destination_of_Transition( Transition inst ) {}
    default public void removeR506_is_destination_of_Transition( Transition inst ) {}
    public TransitionSet R506_is_destination_of_Transition() throws XtumlException;
    default public void addR508_is_origination_of_NoEventTransition( NoEventTransition inst ) {}
    default public void removeR508_is_origination_of_NoEventTransition( NoEventTransition inst ) {}
    public NoEventTransitionSet R508_is_origination_of_NoEventTransition() throws XtumlException;
    default public void setR511_MooreActionHome( MooreActionHome inst ) {}
    public MooreActionHome R511_MooreActionHome() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/StateMachineState.java <==
package io.ciera.tool.sql.ooaofooa.statemachine;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.statemachine.State;
import io.ciera.tool.sql.ooaofooa.instance.I_INS;
import io.ciera.tool.sql.ooaofooa.instance.I_INSSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHome;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransition;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SM;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntry;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntrySet;
import io.ciera.tool.sql.ooaofooa.statemachine.Transition;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;


public interface StateMachineState extends IModelInstance<StateMachineState,Sql> {

    // attributes
    public void setSMstt_ID( UniqueId m_SMstt_ID ) throws XtumlException;
    public UniqueId getSMstt_ID() throws XtumlException;
    public UniqueId getSM_ID() throws XtumlException;
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException;
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException;
    public UniqueId getSMspd_IDdeprecated() throws XtumlException;
    public String getName() throws XtumlException;
    public void setName( String m_Name ) throws XtumlException;
    public int getNumb() throws XtumlException;
    public void setNumb( int m_Numb ) throws XtumlException;
    public int getFinal() throws XtumlException;
    public void setFinal( int m_Final ) throws XtumlException;


    // operations


    // selections
    default public void addR2915_defines_state_of_I_INS( I_INS inst ) {}
    default public void removeR2915_defines_state_of_I_INS( I_INS inst ) {}
    public I_INSSet R2915_defines_state_of_I_INS() throws XtumlException;
    default public void setR4758_State( State inst ) {}
    public State R4758_State() throws XtumlException;
    default public void setR501_SM_SM( SM_SM inst ) {}
    public SM_SM R501_SM_SM() throws XtumlException;
    default public void addR503_receives_StateEventMatrixEntry( StateEventMatrixEntry inst ) {}
    default public void removeR503_receives_StateEventMatrixEntry( StateEventMatrixEntry inst ) {}
    public StateEventMatrixEntrySet R503_receives_StateEventMatrixEntry() throws XtumlException;
    default public void addR506_is_destination_of_Transition( Transition inst ) {}
    default public void removeR506_is_destination_of_Transition( Transition inst ) {}
    public TransitionSet R506_is_destination_of_Transition() throws XtumlException;
    default public void addR508_is_origination_of_NoEventTransition( NoEventTransition inst ) {}
    default public void removeR508_is_origination_of_NoEventTransition( NoEventTransition inst ) {}
    public NoEventTransitionSet R508_is_origination_of_NoEventTransition() throws XtumlException;
    default public void setR511_MooreActionHome( MooreActionHome inst ) {}
    public MooreActionHome R511_MooreActionHome() throws XtumlException;


}
